@@ -1,7 +1,7 @@
 import logging
 
-__version__ = "0.2.15"
-logger = logging.getLogger('pyemd')
+__version__ = "1.1.0"
+logger = logging.getLogger("pyemd")
 
 from PyEMD.EMD import EMD
 from PyEMD.EEMD import EEMD
